==> mozjs128_128.14.0.orig.tar.xz: firefox-128.14.0/js/src/tests/test262/built-ins/Temporal/ZonedDateTime/prototype/equals/argument-string-time-zone-annotation.js <==
// |reftest| skip-if(!this.hasOwnProperty('Temporal')) -- Temporal is not enabled unconditionally
// Copyright (C) 2022 Igalia, S.L. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
esid: sec-temporal.zoneddatetime.prototype.equals
description: Various forms of time zone annotation; critical flag has no effect
features: [Temporal]
---*/

const tests = [
  ["1970-01-01T00:00[UTC]", "UTC", "named, with no offset"],
  ["1970-01-01T00:00[!UTC]", "UTC", "named, with ! and no offset"],
  ["1970-01-01T00:00[+00:00]", "+00:00", "numeric, with no offset"],
  ["1970-01-01T00:00[!+00:00]", "+00:00", "numeric, with ! and no offset"],
  ["1970-01-01T00:00Z[UTC]", "UTC", "named, with Z"],
  ["1970-01-01T00:00Z[!UTC]", "UTC", "named, with Z and !"],
  ["1970-01-01T00:00Z[+00:00]", "+00:00", "numeric, with Z"],
  ["1970-01-01T00:00Z[!+00:00]", "+00:00", "numeric, with Z and !"],
  ["1970-01-01T00:00+00:00[UTC]", "UTC", "named, with offset"],
  ["1970-01-01T00:00+00:00[!UTC]", "UTC", "named, with offset and !"],
  ["1970-01-01T00:00+00:00[+00:00]", "+00:00", "numeric, with offset"],
  ["1970-01-01T00:00+00:00[!+00:00]", "+00:00", "numeric, with offset and !"],
];

tests.forEach(([arg, expectedZone, description]) => {
  const timeZone = new Temporal.TimeZone(expectedZone);
  const instance = new Temporal.ZonedDateTime(0n, timeZone);
  const result = instance.equals(arg);

  assert.sameValue(
    result,
    true,
    `time zone annotation (${description})`
  );
});

reportCompare(0, 0);

==> mozjs140_140.4.0.orig.tar.xz: firefox-140.4.0/js/src/tests/test262/built-ins/Temporal/ZonedDateTime/prototype/equals/argument-string-time-zone-annotation.js <==
// |reftest| shell-option(--enable-temporal) skip-if(!this.hasOwnProperty('Temporal')||!xulRuntime.shell) -- Temporal is not enabled unconditionally, requires shell-options
// Copyright (C) 2022 Igalia, S.L. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
esid: sec-temporal.zoneddatetime.prototype.equals
description: Various forms of time zone annotation; critical flag has no effect
features: [Temporal]
---*/

const tests = [
  ["1970-01-01T00:00[UTC]", "UTC", "named, with no offset"],
  ["1970-01-01T00:00[!UTC]", "UTC", "named, with ! and no offset"],
  ["1970-01-01T00:00[+00:00]", "+00:00", "numeric, with no offset"],
  ["1970-01-01T00:00[!+00:00]", "+00:00", "numeric, with ! and no offset"],
  ["1970-01-01T00:00Z[UTC]", "UTC", "named, with Z"],
  ["1970-01-01T00:00Z[!UTC]", "UTC", "named, with Z and !"],
  ["1970-01-01T00:00Z[+00:00]", "+00:00", "numeric, with Z"],
  ["1970-01-01T00:00Z[!+00:00]", "+00:00", "numeric, with Z and !"],
  ["1970-01-01T00:00+00:00[UTC]", "UTC", "named, with offset"],
  ["1970-01-01T00:00+00:00[!UTC]", "UTC", "named, with offset and !"],
  ["1970-01-01T00:00+00:00[+00:00]", "+00:00", "numeric, with offset"],
  ["1970-01-01T00:00+00:00[!+00:00]", "+00:00", "numeric, with offset and !"],
];

tests.forEach(([arg, expectedZone, description]) => {
  const instance = new Temporal.ZonedDateTime(0n, expectedZone);
  const result = instance.equals(arg);

  assert.sameValue(
    result,
    true,
    `time zone annotation (${description})`
  );
});

reportCompare(0, 0);
